@@ -13,6 +13,7 @@ import (
 	"strings"
 
 	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/go-lib/strv"
 )
 
 type MirrorSource struct {
@@ -111,8 +112,13 @@ const (
 	CustomSourceDir    = "/var/lib/lastore/sources.list.d"
 	OriginSourceDir    = "/etc/apt/sources.list.d"
 	SystemSourceFile   = "/etc/apt/sources.list"
+	SystemSourceDir    = "/var/lib/lastore/systemSource.d"
 	AppStoreList       = "appstore.list"
 	AppStoreSourceFile = "/etc/apt/sources.list.d/" + AppStoreList
+	UnstableSourceList = "deepin-unstable-source.list"
+	UnstableSourceFile = "/etc/apt/sources.list.d/" + UnstableSourceList
+	HweSourceList      = "hwe.list"
+	HweSourceFile      = "/etc/apt/sources.list.d/" + HweSourceList
 	DriverList         = "driver.list"
 	SecurityList       = "security.list"
 	SecuritySourceFile = "/etc/apt/sources.list.d/" + SecurityList // 安全更新源路径
@@ -121,7 +127,7 @@ const (
 
 func GetCategorySourceMap() map[UpdateType]string {
 	return map[UpdateType]string{
-		SystemUpdate: SystemSourceFile,
+		SystemUpdate: SystemSourceDir,
 		//AppStoreUpdate:     AppStoreSourceFile,
 		OnlySecurityUpdate: SecuritySourceFile,
 		UnknownUpdate:      UnknownSourceDir,
@@ -155,10 +161,17 @@ func UpdateUnknownSourceDir() error {
 		logger.Warning(err)
 		return err
 	}
+	nonUnknownSourceFileList := strv.Strv{
+		AppStoreList,
+		SecurityList,
+		DriverList,
+		UnstableSourceFile,
+		HweSourceList,
+	}
 	for _, fileInfo := range sourceDirFileInfos {
 		name := fileInfo.Name()
 		if strings.HasSuffix(name, ".list") {
-			if name != AppStoreList && name != SecurityList && name != DriverList {
+			if !nonUnknownSourceFileList.Contains(name) {
 				unknownSourceFilePaths = append(unknownSourceFilePaths, filepath.Join(OriginSourceDir, name))
 			}
 		}
@@ -174,3 +187,28 @@ func UpdateUnknownSourceDir() error {
 	}
 	return nil
 }
+
+func UpdateSystemSourceDir() error {
+
+	err := os.RemoveAll(SystemSourceDir)
+	if err != nil {
+		logger.Warning(err)
+	}
+	// #nosec G301
+	err = os.MkdirAll(SystemSourceDir, 0755)
+	if err != nil {
+		logger.Warning(err)
+	}
+
+	var systemSourceFilePaths = []string{UnstableSourceFile, SystemSourceFile, HweSourceFile}
+
+	// 创建对应的软链接
+	for _, filePath := range systemSourceFilePaths {
+		linkPath := filepath.Join(SystemSourceDir, filepath.Base(filePath))
+		err = os.Symlink(filePath, linkPath)
+		if err != nil {
+			return fmt.Errorf("create symlink for %q failed: %v", filePath, err)
+		}
+	}
+	return nil
+}
